@@ -21,7 +21,7 @@ NULL
 #' a <- archive(system.file(package = "archive", "extdata", "data.zip"))
 #' a
 #' @export
-archive <- function(file, options = character()) {
+archive <- function(file, options = character(), password = NA_character_) {
   if (!inherits(file, "connection")) {
     file <- file(file, "rb")
   }
@@ -32,7 +32,7 @@ archive <- function(file, options = character()) {
 
   options <- validate_options(options)
 
-  res <- archive_(file, options)
+  res <- archive_(file, options, c(password))
 
   res
 }
@@ -114,10 +114,14 @@ libarchive_version <- function() {
 
 libarchive_zlib_version <- function() {
   version <- libarchive_zlib_version_()
-  if (nzchar(version)) {
-    return(package_version(version))
+  # remove suffix from 1.3.1.zlib-ng and similar
+  version <- sub("[.]?[^0-9.-].*$", "", version)
+  version <- package_version(version, strict = FALSE)
+  if (is.na(version)) {
+    package_version("0.0.0")
+  } else {
+    version
   }
-  package_version("0.0.0")
 }
 
 libarchive_liblzma_version <- function() {
